@@ -1,4 +1,4 @@
-//$Id: add-resource.cc,v 1.5 2001/03/11 18:16:16 cactus Exp $ -*- c++ -*-
+//$Id: add-resource.cc,v 1.7 2001/08/28 15:00:21 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -71,8 +71,9 @@ GUI::AddResourceWin::AddResourceWin ()
 
 GUI::AddResourceWin::~AddResourceWin ()
 {
-    dialog->destroy ();
-    gtk_object_unref (GTK_OBJECT (gui));    
+//    dialog->destroy ();
+    gtk_widget_destroy (GTK_WIDGET (dialog->gtkobj ()));
+    gtk_object_unref (GTK_OBJECT (gui));
 }
 
 void GUI::AddResourceWin::run ()
