@@ -1,4 +1,4 @@
-//$Id: dialog-win.cc,v 1.12 2001/07/14 15:09:51 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.cc,v 1.15 2001/08/31 16:11:37 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,10 +34,7 @@ using namespace Guikachu;
 
 GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
     res (res_),
-    help_combo (Resources::RESOURCE_STRING,
-		SigC::slot (res, &Resources::Dialog::get_help_id),
-		SigC::slot (res, &Resources::Dialog::set_help_id),
-		res->changed),
+    help_combo (Resources::RESOURCE_STRING, res->help_id),
     update_block (true)
 {
     gui = glade_xml_new (GLADEDIR "/guikachu.glade", 0);
@@ -118,7 +115,8 @@ GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
 
 GUI::DialogWindow::~DialogWindow ()
 {
-    window->destroy ();
+//    window->destroy ();
+    gtk_widget_destroy (GTK_WIDGET (window->gtkobj ()));
     gtk_object_unref (GTK_OBJECT (gui));
 }
 
@@ -136,25 +134,25 @@ int GUI::DialogWindow::delete_event_impl (GdkEventAny *e)
 
 void GUI::DialogWindow::update ()
 {
-    gchar *title_buf = g_strdup_printf (_("Dialog: %s"), res->get_id ().c_str ());
+    gchar *title_buf = g_strdup_printf (_("Dialog: %s"), res->id ().c_str ());
     window->set_title (title_buf);
     g_free (title_buf);
 
     update_block = true;
     
-    id_entry->set_text (res->get_id ());
-    title_entry->set_text (res->get_title ());
+    id_entry->set_text (res->id);
+    title_entry->set_text (res->title);
 
     if (text_entry->get_length())
 	text_entry->delete_text (0, text_entry->get_length ());
-    text_entry->insert (res->get_text ());
+    text_entry->insert (res->text);
 
-    type_combo->set_history (res->get_dialog_type ());
+    type_combo->set_history (res->dialog_type);
     
-    vector<string> buttons = res->get_buttons ();
+    vector<string> buttons = res->buttons;
     vector<string>::iterator i;
     unsigned int j;
-    unsigned int default_button = res->get_default_button ();
+    unsigned int default_button = res->default_button;
     
     button_list->items().clear ();
     for (i = buttons.begin (), j = 0;
@@ -179,12 +177,12 @@ void GUI::DialogWindow::update ()
 
 void GUI::DialogWindow::id_entry_cb ()
 {
-    res->set_id (id_entry->get_text ());
+    res->id = id_entry->get_text ();
 }
 
 void GUI::DialogWindow::title_entry_cb ()
 {
-    res->set_title (title_entry->get_text ());
+    res->title = title_entry->get_text ();
 }
 
 void GUI::DialogWindow::text_entry_cb ()
@@ -193,22 +191,22 @@ void GUI::DialogWindow::text_entry_cb ()
 	return;
 
     int saved_pos = text_entry->get_position ();
-    res->set_text (text_entry->get_chars (0, text_entry->get_length ()));
+    res->text = text_entry->get_chars (0, text_entry->get_length ());
     gtk_editable_set_position (GTK_EDITABLE (text_entry->gtkobj ()), saved_pos);
 }
 
 void GUI::DialogWindow::type_menu_cb (Resources::DialogType type)
 {
-    res->set_dialog_type (type);
+    res->dialog_type = type;
 }
 
 void GUI::DialogWindow::dialog_add_cb (string name)
 {
     if (name != "")
     {
-	vector<string> buttons = res->get_buttons ();	
+	vector<string> buttons = res->buttons;
 	buttons.push_back (name);
-	res->set_buttons (buttons);
+	res->buttons = buttons;
     }
 }
 
@@ -243,12 +241,12 @@ void GUI::DialogWindow::button_remove_cb ()
     Gtk::List::SelectionList::iterator sel = button_list->selection ().begin ();  
     unsigned int index = GPOINTER_TO_UINT ((*sel)->get_user_data ());
 
-    vector<string> buttons = res->get_buttons ();
+    vector<string> buttons = res->buttons;
     buttons.erase (buttons.begin () + index);
-    res->set_buttons (buttons);
+    res->buttons = buttons;
 
-    if (index == res->get_default_button ())
-	res->set_default_button (0);
+    if (index == res->default_button)
+	res->default_button = 0;
 }
 
 void GUI::DialogWindow::button_default_cb ()
@@ -258,7 +256,7 @@ void GUI::DialogWindow::button_default_cb ()
     Gtk::List::SelectionList::iterator sel = button_list->selection ().begin ();
     unsigned int index = GPOINTER_TO_UINT ((*sel)->get_user_data ());
 
-    res->set_default_button (index);
+    res->default_button = index;
 
     button_list->select_item (index);
 }
@@ -271,18 +269,18 @@ void GUI::DialogWindow::button_up_cb ()
     unsigned int index = GPOINTER_TO_UINT ((*(sel_list.begin ()))->get_user_data ());
     g_return_if_fail (index != 0);
 
-    vector<string> buttons = res->get_buttons ();
+    vector<string> buttons = res->buttons;
     vector<string>::iterator curr = buttons.begin () + index;
     vector<string>::iterator prev = curr - 1;
     iter_swap (curr, prev);    
-    res->set_buttons (buttons);
+    res->buttons = buttons;
 
-    unsigned int old_default = res->get_default_button ();
+    unsigned int old_default = res->default_button;
 
     if (index == old_default)
-	res->set_default_button (index - 1);
+	res->default_button = index - 1;
     if (index - 1 == old_default)
-	res->set_default_button (index);
+	res->default_button = index;
 
     button_list->select_item (index - 1);
 }
@@ -295,18 +293,18 @@ void GUI::DialogWindow::button_down_cb ()
     unsigned int index = GPOINTER_TO_UINT ((*(sel_list.begin ()))->get_user_data ());
     g_return_if_fail (index < button_list->items ().size () - 1);
 
-    vector<string> buttons = res->get_buttons ();
+    vector<string> buttons = res->buttons;
     vector<string>::iterator curr = buttons.begin () + index;
     vector<string>::iterator next = curr + 1;
     iter_swap (curr, next);
-    res->set_buttons (buttons);
+    res->buttons = buttons;
 
-    unsigned int old_default = res->get_default_button ();
+    unsigned int old_default = res->default_button;
 
     if (index == old_default)
-	res->set_default_button (index + 1);
+	res->default_button = index + 1;
     if (index + 1 == old_default)
-	res->set_default_button (index);
+	res->default_button = index;
 
     button_list->select_item (index + 1);
 }
