@@ -1,4 +1,4 @@
-//$Id: button-canvas.h,v 1.1 2001/04/30 20:47:26 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.h,v 1.2 2001/05/14 16:54:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,13 +31,12 @@ namespace Guikachu
 	    class ButtonCanvasItem: public CanvasItem
 	    {
 		Widgets::Button    *widget;
-		FormEditor::Form   *form;
 		Gnome::CanvasGroup *group;
 	    public:
 		ButtonCanvasItem (Widgets::Button  *widget,
 				  FormEditor::Form *form);
 	    private:
-		void update ();
+		virtual void update ();
 	    };
 	}
     }
