@@ -1,4 +1,4 @@
-//$Id: button.cc,v 1.17 2001/09/02 20:12:57 cactus Exp $ -*- c++ -*-
+//$Id: button.cc,v 1.21 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -44,116 +44,75 @@ Button::~Button ()
     delete editor;
 }
 
-Gtk::Widget *Button::get_editor ()
+Gtk::Widget *Button::create_editor ()
 {
     return editor->get_editor ();
 }
 
-bool Button::load (xmlDocPtr doc,
-		   xmlNodePtr node)
+CanvasItem* Button::create_canvas_item (GUI::FormEditor::Form *form)
 {
-    xmlNodePtr curr_node;
+    return new ButtonCanvasItem (this, form);
+}
 
-    bool xml_pos_set = false;
-    bool xml_text_set = false;
-    
-    gchar *xml_val;
 
+bool Button::load (StorageNode &node)
+{
     /* Non-NULL default values */
     usable = false;
     frame = BUTTON_FRAME_NONE;
     
-#define XML_HAS_NAME(node, val) (!strcmp ((char*) node->name, val))
-    
-#define XML_APPLY(attr)       \
-	if (xml_val)          \
-	{                     \
-	    attr = xml_val;   \
-	    xmlFree (xml_val);\
-	}
-
-#define XML_GET_CONTENT(node, attr) \
-	xml_val = (char*)xmlNodeListGetString (doc, node->xmlChildrenNode, 1); \
-        XML_APPLY(attr);
-    
-#define XML_GET_NUM_PROP(node, prop, attr)			\
-	xml_val = (char*)xmlGetProp (node, (xmlChar*) prop);	\
-	if (xml_val)						\
-	{							\
-	    attr = atoi(xml_val);				\
-	    xmlFree (xml_val);					\
-	}
-
-    for (curr_node  = node->xmlChildrenNode;
-	 curr_node != NULL;
-	 curr_node  = curr_node->next)
+    for (StorageNode curr_node  = node.children ();
+	 curr_node; curr_node++)
     {
-	if (XML_HAS_NAME (curr_node, "pos") && !xml_pos_set)
+	if (curr_node.name () == "pos")
 	{
-	    XML_GET_NUM_PROP (curr_node, "x", x);
-	    XML_GET_NUM_PROP (curr_node, "y", y);
+	    x = curr_node.get_prop<int> ("x");
+	    y = curr_node.get_prop<int> ("y");
 
-	    xml_val = (char*)xmlGetProp (curr_node, (xmlChar*) "width");
-	    if (!xml_val)
+	    string width_str = curr_node.get_prop<string> ("width");
+	    if (width_str == "auto")
 	    {
 		manual_width = false;
+		width = 0;
 	    } else {
-		if (!strcasecmp (xml_val, "auto"))
-		{
-		    manual_width = false;
-		} else {
-		    manual_width = true;
-		    width = atoi (xml_val);
-		}
-		xmlFree (xml_val);
+		manual_width = true;
+		width = atoi (width_str.c_str ());
 	    }
-	    
-	    xml_val = (char*)xmlGetProp (curr_node, (xmlChar*) "height");
-	    if (!xml_val)
+
+	    string height_str = curr_node.get_prop<string> ("height");
+	    if (height_str == "auto")
 	    {
 		manual_height = false;
+		height = 0;
 	    } else {
-		if (!strcasecmp (xml_val, "auto"))
-		{
-		    manual_height = false;
-		} else {
-		    manual_height = true;
-		    height = atoi (xml_val);
-		}
-		xmlFree (xml_val);
+		manual_height = true;
+		height = atoi (height_str.c_str ());
 	    }
-	    
-	    xml_pos_set = true;
 	}
-	else if (XML_HAS_NAME (curr_node, "text") && !xml_text_set)
+	else if (curr_node.name () == "text")
 	{
-	    XML_GET_CONTENT (curr_node, text);
-	    XML_GET_NUM_PROP (curr_node, "font", font);
-		
-	    xml_text_set = true;
+	    text = curr_node.get_content ();
+	    font = curr_node.get_prop <int> ("font");
 	}
-	else if (XML_HAS_NAME (curr_node, "frame"))
+	else if (curr_node.name () == "frame")
 	{
-	    if (xmlGetProp (curr_node, (xmlChar*) "bold"))
+	    if (curr_node.get_prop<string> ("bold") != "")
 		frame = BUTTON_FRAME_BOLD;
 	    else
 		frame = BUTTON_FRAME_SIMPLE;
 	}
-	else if (XML_HAS_NAME (curr_node, "usable"))
-	{
+	else if (curr_node.name () == "usable")
 	    usable = true;
-	}
-	else if (XML_HAS_NAME (curr_node, "repeat"))
-	{
+	else if (curr_node.name () == "repeat")
 	    repeat = true;
-	}
-	else if (XML_HAS_NAME (curr_node, "anchor_right"))
-	{
+	else if (curr_node.name () == "anchor_right")
 	    anchor_right = true;
-	}
+	else if (curr_node.name () == "usable")
+	    usable = true;
 	else
 	    g_warning ("Error parsing `button' widget: "
-		       "unexpected element `%s'", curr_node->name);
+		       "unexpected element `%s'",
+		       curr_node.name ().c_str ());
     }
 
     changed ();
@@ -161,61 +120,49 @@ bool Button::load (xmlDocPtr doc,
     return true;
 }
 
-void Button::save (xmlNodePtr node) const
+void Button::save (StorageNode &node) const
 {
-    xmlNodePtr my_node;
-    gchar *buffer;
-
+    StorageNode my_node;
+    
     /* Position */
-    my_node = xmlNewChild (node, NULL, (xmlChar*) "pos", NULL);
-    buffer = g_strdup_printf ("%d", int (x));
-    xmlSetProp (my_node, (xmlChar*) "x", (xmlChar*) buffer);
-    g_free (buffer);
-    buffer = g_strdup_printf ("%d", int (y));
-    xmlSetProp (my_node, (xmlChar*) "y", (xmlChar*) buffer);
-    g_free (buffer);
+    my_node = node.add_node ("pos");
+    my_node.set_prop ("x", x);
+    my_node.set_prop ("y", y);
 
     /* Size */
     if (manual_width)
-	buffer = g_strdup_printf ("%d", int (width));
+	my_node.set_prop ("width", width);
     else
-	buffer = g_strdup ("auto");
-    xmlSetProp (my_node, (xmlChar*) "width", (xmlChar*) buffer);
-    g_free (buffer);
+	my_node.set_prop ("width", "auto");
 
     if (manual_height)
-	buffer = g_strdup_printf ("%d", int (height));
+	my_node.set_prop ("height", height);
     else
-	buffer = g_strdup ("auto");
-    xmlSetProp (my_node, (xmlChar*) "height", (xmlChar*) buffer);
-    g_free (buffer);
-
+	my_node.set_prop ("height", "auto");
+    
     /* Frame */
     if (frame != BUTTON_FRAME_NONE)
     {
-	my_node = xmlNewChild (node, NULL, (xmlChar*) "frame", NULL);
+	my_node = node.add_node ("frame");
 	if (frame == BUTTON_FRAME_BOLD)
-	    xmlSetProp (my_node, (xmlChar*) "bold", (xmlChar*) "bold");
+	    my_node.set_prop ("bold", "bold");
     }
     
     /* Usable */
     if (usable)
-	my_node = xmlNewChild (node, NULL, (xmlChar*) "usable", NULL);
+	node.add_node ("usable");
 
     /* Repeating */
     if (repeat)
-	my_node = xmlNewChild (node, NULL, (xmlChar*) "repeat", NULL);
+	node.add_node ("repeat");
 
     /* Anchor_right */
     if (anchor_right)
-	my_node = xmlNewChild (node, NULL, (xmlChar*) "anchor_right", NULL);
+	node.add_node ("anchor_right");
     
     /* Label and font */
-    my_node = xmlNewChild (node, NULL, (xmlChar*) "text",
-			   (xmlChar*) string (text).c_str ());
-    buffer = g_strdup_printf ("%d", int (font));
-    xmlSetProp (my_node, (xmlChar*) "font", (xmlChar*) buffer);
-    g_free (buffer);
+    my_node = node.add_node ("text", text);
+    my_node.set_prop ("font", font);
 }
 
 void Button::save_rcp (ostream &ostr) const
@@ -273,11 +220,6 @@ void Button::save_rcp (ostream &ostr) const
     g_free (width_str);
 }
 
-CanvasItem* Button::get_canvas_item (GUI::FormEditor::Form *form)
-{
-    return new ButtonCanvasItem (this, form);
-}
-
 int Button::get_display_width ()
 {
     if (manual_width)
@@ -293,5 +235,5 @@ int Button::get_display_height ()
 	return height;
 
     int text_height = get_font_height (font);
-    return text_height + 3;
+    return text_height + 2;
 }
