@@ -1,4 +1,4 @@
-//$Id: checkbox-canvas.cc,v 1.8 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: checkbox-canvas.cc,v 1.11 2001/09/20 16:15:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -46,7 +46,6 @@ void CheckboxCanvasItem::update ()
 	delete group;
 
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
-    set_canvas_item (group);
     
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
@@ -72,8 +71,8 @@ void CheckboxCanvasItem::update ()
     Gnome::CanvasPolygon *item = new Gnome::CanvasPolygon (*group, frame_points);
     item->set_width_units (0);
     
-    int text_x = x1 + 18;
-    int text_y = y1 + height / 2;
+    int text_x = x1 + 17;
+    int text_y = y1 + height / 2 - 2;
 
     GdkPixbuf *pixbuf;
     if (widget->toggled)
@@ -90,15 +89,20 @@ void CheckboxCanvasItem::update ()
     gnome_canvas_item_new (group->gtkobj (),
 			   gnome_canvas_pixbuf_get_type (),
 			   "pixbuf", pixbuf,
-			   "x", (double)widget->x + 3,
-			   "y", (double)widget->y + 3,
+			   "x", (double)widget->x + 2,
+			   "y", (double)widget->y + 1,
 			   0);
     gdk_pixbuf_unref (pixbuf);
 
-    draw_text (*group,
-	       widget->text, widget->font,
-	       text_x, text_y,
-	       widget->usable,
-	       GTK_ANCHOR_WEST,
-	       width - 18, height);
+    if (width > 18)
+    {
+	draw_text (*group,
+		   widget->text, widget->font,
+		   text_x, text_y,
+		   widget->usable,
+		   GTK_ANCHOR_WEST,
+		   width - 18, height);
+    }
+    
+    set_canvas_item (group);
 }
