@@ -1,4 +1,4 @@
-//$Id: form-editor.cc,v 1.10 2001/07/08 17:03:11 cactus Exp $ -*- c++ -*-
+//$Id: form-editor.cc,v 1.12 2001/09/22 18:54:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,7 +30,12 @@ using Guikachu::GUI::FormEditor::Font;
 
 #define GUIKACHU_TITLE_FONT 1
 
-Font &FormEditor::get_font (int font_num)
+static GdkPixbuf* clip_pixbuf (GdkPixbuf    *src,
+			       GtkAnchorType anchor,
+			       int           clip_width,
+			       int           clip_height);
+
+const Font &FormEditor::get_font (int font_num)
 {
     static Font standard_fonts[3];
     static bool init[3] = {false, false, false};
@@ -62,27 +67,20 @@ Font &FormEditor::get_font (int font_num)
     return standard_fonts[font_num];
 }
 
-Font &FormEditor::get_title_font ()
+const Font &FormEditor::get_title_font ()
 {
     return get_font (GUIKACHU_TITLE_FONT);
 }
 
 unsigned int FormEditor::get_font_height (int font_num)
 {
-    switch (font_num)
-    {
-    case 2:
-	return 14;
-	break;
-    default:
-	return 11;
-	break;
-    }
+    const Font &font = get_font (font_num);
+    return font.get_height ();
 }
 
 unsigned int FormEditor::get_string_width (int font_num, const string& text)
 {
-    Font &font = get_font (font_num);
+    const Font &font = get_font (font_num);
     return font.string_width (text);
 }
 
@@ -122,57 +120,61 @@ Gnome::CanvasItem* FormEditor::render_text (Gnome::CanvasGroup &group,
     if (!pixbuf)
 	return 0;
     
-    int width = gdk_pixbuf_get_width (pixbuf);
-    int height = gdk_pixbuf_get_height (pixbuf);
+    GdkPixbuf *clipped_pixbuf;
+    if (clip_width || clip_height)
+	clipped_pixbuf = clip_pixbuf (pixbuf, anchor, clip_width, clip_height);
+    else
+	clipped_pixbuf = gdk_pixbuf_ref (pixbuf);
+    gdk_pixbuf_unref (pixbuf);
     
+    int width = gdk_pixbuf_get_width (clipped_pixbuf);
+    int height = gdk_pixbuf_get_height (clipped_pixbuf);
+
+    // Horizontal offset
     switch (anchor)
     {
     case GTK_ANCHOR_NORTH_WEST:
-	break;
-	
-    case GTK_ANCHOR_CENTER:
-	x -= width / 2;
-	y -= height / 2;
-	break;
-
-    case GTK_ANCHOR_NORTH:
-	x -= width / 2;
-	break;
-    case GTK_ANCHOR_SOUTH:
-	x += width / 2;
-	break;
-
     case GTK_ANCHOR_WEST:
-	y -= height / 2;
-	break;
-    case GTK_ANCHOR_EAST:
-	y += height / 2;
-	break;
-
     case GTK_ANCHOR_SOUTH_WEST:
-	y -= height;
 	break;
-
+    case GTK_ANCHOR_NORTH:
+    case GTK_ANCHOR_CENTER:
+    case GTK_ANCHOR_SOUTH:
+	x -= width / 2;
+	break;
     case GTK_ANCHOR_NORTH_EAST:
-	x -= width;
-	break;
-
+    case GTK_ANCHOR_EAST:
     case GTK_ANCHOR_SOUTH_EAST:
-	y -= height;
 	x -= width;
-	break;
     }
 
-    /* FIXME: implement clipping */
+    // Vertical offset
+    switch (anchor)
+    {
+    case GTK_ANCHOR_NORTH_WEST:
+    case GTK_ANCHOR_NORTH:
+    case GTK_ANCHOR_NORTH_EAST:
+	break;
+    case GTK_ANCHOR_WEST:
+    case GTK_ANCHOR_CENTER:
+    case GTK_ANCHOR_EAST:
+	y -= height / 2;
+	break;
+    case GTK_ANCHOR_SOUTH_WEST:
+    case GTK_ANCHOR_SOUTH:
+    case GTK_ANCHOR_SOUTH_EAST:
+	y -= height;
+	break;
+    }
 
     // Draw the text
     gnome_canvas_item_new (text_group->gtkobj (),
 			   gnome_canvas_pixbuf_get_type (),
-			   "pixbuf", pixbuf,
+			   "pixbuf", clipped_pixbuf,
 			   "x", (double)x,
 			   "y", (double)y,
 			   0);
-    gdk_pixbuf_unref (pixbuf);
+    gdk_pixbuf_unref (clipped_pixbuf);
 
     // Draw a transparent background block (to get mouse events for
     // the whole area)
@@ -190,3 +192,78 @@ Gnome::CanvasItem* FormEditor::render_text (Gnome::CanvasGroup &group,
     
     return text_group;
 }
+
+GdkPixbuf* clip_pixbuf (GdkPixbuf     *src,
+			GtkAnchorType  anchor,
+			int            clip_width,
+			int            clip_height)
+{
+    GdkPixbuf *dest;
+    
+    int width = gdk_pixbuf_get_width (src);
+    int height = gdk_pixbuf_get_height (src);
+
+    if (clip_width <= 0 || clip_width > width)
+	clip_width = width;
+
+    if (clip_height <= 0 || clip_height > height)
+	clip_height = height;
+
+    int src_x = 0;
+    int src_y = 0;
+
+    /* Set src_x */
+    switch (anchor)
+    {
+    case GTK_ANCHOR_NORTH_WEST:
+    case GTK_ANCHOR_WEST:
+    case GTK_ANCHOR_SOUTH_WEST:
+	src_x = 0;
+	break;
+
+    case GTK_ANCHOR_NORTH_EAST:
+    case GTK_ANCHOR_EAST:
+    case GTK_ANCHOR_SOUTH_EAST:
+	src_x = width - clip_width;
+	break;
+
+    case GTK_ANCHOR_NORTH:
+    case GTK_ANCHOR_CENTER:
+    case GTK_ANCHOR_SOUTH:
+	src_x = (width / 2) - (clip_width / 2);
+	break;
+    }
+
+    /* Set src_y */
+    switch (anchor)
+    {
+    case GTK_ANCHOR_NORTH_WEST:
+    case GTK_ANCHOR_NORTH:
+    case GTK_ANCHOR_NORTH_EAST:
+	src_y = 0;
+	break;
+
+    case GTK_ANCHOR_SOUTH_WEST:
+    case GTK_ANCHOR_SOUTH:
+    case GTK_ANCHOR_SOUTH_EAST:
+	src_y = height - clip_height;
+	break;
+
+    case GTK_ANCHOR_WEST:
+    case GTK_ANCHOR_CENTER:
+    case GTK_ANCHOR_EAST:
+	src_y = (height / 2) - (clip_height / 2);
+	break;
+    }
+
+    dest = gdk_pixbuf_new (GDK_COLORSPACE_RGB, true, 8,
+			   clip_width, clip_height);
+
+    gdk_pixbuf_copy_area (src,
+			  src_x, src_y,
+			  clip_width, clip_height,
+			  dest, 0, 0);
+
+    return dest;
+}
+
