@@ -1,4 +1,4 @@
-//$Id: form.h,v 1.7 2001/08/10 16:10:35 cactus Exp $ -*- c++ -*-
+//$Id: form.h,v 1.8 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -61,7 +61,7 @@ namespace Guikachu
 		Gtk::Widget *get_editor ();
 		
 		Gnome::CanvasGroup *get_canvas () const;
-		SigC::Signal0<void> show_editor;
+		SigC::Signal0<void> clicked;
 	    private:
 		void update ();
 		
@@ -69,9 +69,9 @@ namespace Guikachu
 		void draw_frame ();
 		void draw_title ();
 		
-		void draw_frame_modal ();
+		void draw_frame_modal    ();
 		void draw_frame_nonmodal ();
-		void draw_title_modal ();
+		void draw_title_modal    ();
 		void draw_title_nonmodal ();
 		
 		/* Callbacks */
