@@ -1,4 +1,4 @@
-//$Id: label.h,v 1.9 2001/08/18 16:22:55 cactus Exp $ -*- c++ -*-
+//$Id: label.h,v 1.12 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -54,15 +54,15 @@ namespace Guikachu
 	    
 	    virtual Type get_type () const { return WIDGET_LABEL; };
 	    
-	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
-	    virtual Gtk::Widget *get_editor ();
+	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
+	    virtual Gtk::Widget                 *create_editor ();
 	    
 	    Property<bool>   usable;
 	    
 	private:
 	    // Persistance
-	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
-	    virtual void save (xmlNodePtr node) const;
+	    virtual bool load (StorageNode &node);
+	    virtual void save (StorageNode &node) const;
 	    virtual void save_rcp (ostream &ostr) const;
 	};
     }
