@@ -1,4 +1,4 @@
-//$Id: list-canvas.cc,v 1.8 2001/08/31 16:11:38 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.cc,v 1.10 2001/09/22 19:07:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,7 +41,6 @@ void ListCanvasItem::update ()
 	delete group;
     
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
-    set_canvas_item (group);
 
     int font_num = widget->font;    
     int height = get_font_height (font_num) * widget->visible_items;
@@ -52,8 +51,8 @@ void ListCanvasItem::update ()
     vector<string> listitems = widget->items;
 
     // FIXME: size() is unsigned, visible_items is signed
-    int visible_strings = MIN (widget->visible_items,
-			       listitems.size ());
+    int num_items = listitems.size ();
+    int visible_strings = MIN (widget->visible_items, num_items);
     
     int line_spacing = get_font_height (font_num);
     int text_y = widget->y;
@@ -93,4 +92,6 @@ void ListCanvasItem::update ()
     *(new Gnome::CanvasPolygon (*group, frame_points))
 	<< width_units (1)
 	<< outline_color (usable ? GUIKACHU_FGC : GUIKACHU_FGC_DISABLED);    
+
+    set_canvas_item (group);
 }
