@@ -1,4 +1,4 @@
-//$Id: palette.cc,v 1.5 2001/09/05 17:08:53 cactus Exp $ -*- c++ -*-
+//$Id: palette.cc,v 1.8 2001/09/22 19:21:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,21 +26,17 @@
 #include <gtk--/box.h>
 #include <gtk--/separator.h>
 
+#include "form-editor/widget-util.h"
+
 using namespace Guikachu::GUI;
 
+namespace {
 #include "pixmaps/none.xpm"
-#include "pixmaps/label.xpm"
-#include "pixmaps/button.xpm"
-#include "pixmaps/pushbutton.xpm"
-#include "pixmaps/graffiti.xpm"
-#include "pixmaps/selector-trigger.xpm"
-#include "pixmaps/checkbox.xpm"
-#include "pixmaps/list.xpm"
-#include "pixmaps/popup-trigger.xpm"
-#include "pixmaps/scrollbar.xpm"
-
+}
+    
 Palette::Palette ():
     Gtk::Window (GTK_WINDOW_DIALOG),
+    sticky (false),
     inside_button_cb (false)
 {
     set_title (_("Widget palette"));
@@ -61,42 +57,49 @@ Palette::Palette ():
     
     Gtk::Table *table = new Gtk::Table (3, 5);
 
-#define PALETTE_ADD_BUTTON(type,tip,xpm,x,y)				\
-    table->attach (*manage (create_button (type, tip, xpm)), 		\
-		   x, (x + 1), y, (y + 1),				\
-		   0, 0);						\
+#define PALETTE_ADD_BUTTON(type,tip,x,y)						\
+    table->attach (*manage (create_button (type, tip, Widgets::type_icon (type))),	\
+		   x, (x + 1), y, (y + 1),						\
+		   0, 0);								\
     
     PALETTE_ADD_BUTTON(Widgets::WIDGET_LABEL,
-		       _("Static text label"), label_xpm,
+		       _("Static text label"),
 		       0, 0);
+    PALETTE_ADD_BUTTON(Widgets::WIDGET_TEXT_FIELD,
+		       _("Editable, dynamic text field"),
+		       1, 0);
     PALETTE_ADD_BUTTON(Widgets::WIDGET_GRAFFITI,
-		       _("Graffiti state indicator"), graffiti_xpm,
+		       _("Graffiti state indicator"),
 		       2, 0);    
 
     PALETTE_ADD_BUTTON(Widgets::WIDGET_BUTTON,
-		       _("Clickable button"), button_xpm,
+		       _("Clickable button"),
 		       0, 1);
     PALETTE_ADD_BUTTON(Widgets::WIDGET_PUSHBUTTON,
-		       _("Pushbutton"), pushbutton_xpm,
+		       _("Pushbutton"),
 		       1, 1);
     PALETTE_ADD_BUTTON(Widgets::WIDGET_SELECTOR_TRIGGER,
-		       _("Selector trigger"), selector_trigger_xpm,
+		       _("Selector trigger"),
 		       2, 1);
     
     PALETTE_ADD_BUTTON(Widgets::WIDGET_CHECKBOX,
-		       _("Check box"), checkbox_xpm,
+		       _("Check box"),
 		       0, 2);
 
     PALETTE_ADD_BUTTON(Widgets::WIDGET_LIST,
-		       _("List"), list_xpm,
+		       _("List"),
 		       2, 2);
 
     PALETTE_ADD_BUTTON(Widgets::WIDGET_POPUP_TRIGGER,
-		       _("Popup trigger"), popup_trigger_xpm,
+		       _("Popup trigger"),
 		       1, 2);
 
     PALETTE_ADD_BUTTON(Widgets::WIDGET_SCROLLBAR,
-		       _("Vertical scroll bar"), scrollbar_xpm,
+		       _("Vertical scroll bar"),
+		       0, 3);
+
+    PALETTE_ADD_BUTTON(Widgets::WIDGET_SCROLLBAR,
+		       _("Vertical scroll bar"),
 		       0, 3);
 		       
 #undef PALETTE_ADD_BUTTON
@@ -110,15 +113,16 @@ Gtk::ToggleButton * Palette::create_button (Widgets::Type       type,
 					    const string&       tooltip,
 					    const char * const *icon_xpm)
 {
+    using namespace SigC;
+    
     Gtk::ToggleButton *button = new Gtk::ToggleButton;		
 
     button->set_relief (GTK_RELIEF_NONE);
     button->add (*manage (new Gtk::Pixmap (icon_xpm)));
     button->set_user_data (GINT_TO_POINTER (type));
-
-    button->clicked.connect (
-	bind (slot (this, &Palette::widget_button_cb), type));
-
+    
+    button->clicked.connect (bind (slot (this, &Palette::widget_button_cb), type));
+    
     tips.set_tip (*button, tooltip);
 
     buttons.push_front (button);
@@ -128,7 +132,8 @@ Gtk::ToggleButton * Palette::create_button (Widgets::Type       type,
 
 void Palette::palette_applied ()
 {
-    widget_button_cb (Widgets::WIDGET_NONE);
+    if (!sticky)
+	set_selection (Widgets::WIDGET_NONE);
 }
 
 int Palette::delete_event_impl (GdkEventAny *e)
@@ -138,6 +143,17 @@ int Palette::delete_event_impl (GdkEventAny *e)
 }
 
 void Palette::widget_button_cb (Widgets::Type type)
+{
+    GdkModifierType modifiers;
+    int dummy;
+    
+    get_window ().get_pointer (dummy, dummy, modifiers);
+
+    sticky = (modifiers & GDK_CONTROL_MASK);
+    set_selection (type);
+}
+
+void Palette::set_selection (Widgets::Type type)
 {
     if (inside_button_cb)
 	return;
