@@ -1,4 +1,4 @@
-//$Id: pushbutton-canvas.cc,v 1.7 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton-canvas.cc,v 1.9 2001/09/19 21:13:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -39,15 +39,14 @@ void PushButtonCanvasItem::update ()
 	delete group;
 
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
-    set_canvas_item (group);
     
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
 
     /* Don't ask about the +1, I have no idea... */
-    int x1 = widget->x;
+    int x1 = widget->x - 1;
     int x2 = x1 + width + 1;
-    int y1 = widget->y;
+    int y1 = widget->y - 1;
     int y2 = y1 + height + 2;
 
     /* A Polygon is used instead of a Rectangle to get mouse events
@@ -70,7 +69,7 @@ void PushButtonCanvasItem::update ()
     else
 	frame_item->set_outline_color (GUIKACHU_FGC_DISABLED);
     
-    int text_x = x1 + width / 2;
+    int text_x = x1 + width / 2 + 1;
     int text_y = y1 + height / 2 + 1;
 
     draw_text (*group,
@@ -79,4 +78,6 @@ void PushButtonCanvasItem::update ()
 	       widget->usable,
 	       GTK_ANCHOR_CENTER,
 	       width, height);
+
+    set_canvas_item (group);
 }
