@@ -1,4 +1,4 @@
-//$Id: scrollbar.h,v 1.1 2001/09/01 13:10:16 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.h,v 1.4 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -53,8 +53,8 @@ namespace Guikachu
 	    
 	    virtual Type get_type () const { return WIDGET_SCROLLBAR; };
 	    
-	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
-	    virtual Gtk::Widget *get_editor ();
+	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
+	    virtual Gtk::Widget                 *create_editor ();
 
 	    virtual int get_display_width ();
 	    virtual int get_display_height ();
@@ -64,8 +64,8 @@ namespace Guikachu
 	    
 	private:
 	    // Persistance
-	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
-	    virtual void save (xmlNodePtr node) const;
+	    virtual bool load (StorageNode &node);
+	    virtual void save (StorageNode &node) const;
 	    virtual void save_rcp (ostream &ostr) const;
 	};
     }
