@@ -1,4 +1,4 @@
-//$Id: selector-trigger-canvas.cc,v 1.8 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-canvas.cc,v 1.11 2001/09/22 19:07:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -39,7 +39,6 @@ void SelectorTriggerCanvasItem::update ()
 	delete group;
 
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
-    set_canvas_item (group);
     
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
@@ -63,7 +62,7 @@ void SelectorTriggerCanvasItem::update ()
     frame_points.push_back (Point (x1, y1));
 
     /* Data for the GdkBitmap to use as an outline stipple */
-    char stipple_bits[] = {
+    static const char stipple_bits[] = {
 	0x01, 0x02, };
 
     Gnome::CanvasPolygon *frame_item = new Gnome::CanvasPolygon (*group, frame_points);    
@@ -80,8 +79,8 @@ void SelectorTriggerCanvasItem::update ()
     else
 	frame_item->set_outline_color (GUIKACHU_FGC_DISABLED);
     
-    int text_x = x1 + 4;
-    int text_y = y1 + height / 2;
+    int text_x = x1 + 3;
+    int text_y = y1 + height / 2 - 1;
 
     draw_text (*group,
 	       widget->text, widget->font,
@@ -89,4 +88,6 @@ void SelectorTriggerCanvasItem::update ()
 	       widget->usable,
 	       GTK_ANCHOR_WEST,
 	       width, height);
+
+    set_canvas_item (group);
 }
