@@ -1,4 +1,4 @@
-//$Id: widget.cc,v 1.11 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
+//$Id: widget.cc,v 1.12 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,14 +25,49 @@ using namespace Guikachu;
 Widgets::Widget::Widget (Resources::Form *owner_,
 			 const string&    id_):
     owner (owner_),
+    editor (0),
     id (changed, id_),
     x (changed, 0),
     y (changed, 0)
 {
-}   
+}
+
+Widgets::Widget::~Widget ()
+{
+#if 0
+    // FIXME: This will need a real PropertyEditor abstract class
+    if (editor)
+	delete editor;
+#endif
+    
+    for (canvas_item_map_t::iterator i = canvas_items.begin ();
+	 i != canvas_items.end (); i++)
+	delete i->second;
+}
 
 ostream& Widgets::operator<< (ostream &ostr, const Widget* res)
 {
     res->save_rcp (ostr);
     return ostr;
 }
+
+Gtk::Widget *Widgets::Widget::get_editor ()
+{
+    if (!editor)
+	editor = create_editor ();
+
+    return editor;
+}
+
+GUI::FormEditor::CanvasItem *Widgets::Widget::get_canvas_item (GUI::FormEditor::Form *form)
+{
+    GUI::FormEditor::CanvasItem *ret;
+    
+    canvas_item_map_t::iterator found = canvas_items.find (form);
+    if (found == canvas_items.end ())
+	ret = canvas_items[form] = create_canvas_item (form);
+    else
+	ret = found->second;
+
+    return ret;
+}
