@@ -1,4 +1,4 @@
-//$Id: widget.h,v 1.19 2001/09/01 13:10:16 cactus Exp $ -*- c++ -*-
+//$Id: widget.h,v 1.24 2001/09/22 17:59:13 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,7 +34,8 @@ namespace Guikachu
 	    WIDGET_CHECKBOX,
 	    WIDGET_LIST,
 	    WIDGET_POPUP_TRIGGER,
-	    WIDGET_SCROLLBAR
+	    WIDGET_SCROLLBAR,
+	    WIDGET_TEXT_FIELD
 	};
 
 	class Widget;
@@ -42,6 +43,7 @@ namespace Guikachu
 }
 
 #include <string>
+#include <map>
 #include <iostream>
 #include <gnome-xml/tree.h>
 #include <sigc++/basic_signal.h>
@@ -54,18 +56,22 @@ namespace Guikachu
 
 namespace Guikachu
 {
-    
     namespace Widgets
     {
 	class Widget: public SigC::Object
 	{
 	protected:
-	    Resources::Form *owner;
-
+	    typedef map<GUI::FormEditor::Form*,
+		        GUI::FormEditor::CanvasItem*>   canvas_item_map_t;
+	    
+	    Resources::Form            *owner;
+	    mutable Gtk::Widget       *editor;
+	    mutable canvas_item_map_t  canvas_items;
+	    
 	    Widget (Resources::Form *owner, const string& id);
 	    
 	public:
-	    virtual ~Widget () {};
+	    virtual ~Widget ();
 	    
 	    virtual Type get_type () const = 0;
 
@@ -78,17 +84,21 @@ namespace Guikachu
 	    Property<int> y;
 
 	    // Preview-related methods
-	    virtual GUI::FormEditor::CanvasItem *get_canvas_item(GUI::FormEditor::Form *form) = 0;
-	    virtual Gtk::Widget *get_editor () = 0;
+	    GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
+	    Gtk::Widget                 *get_editor      ();
 
-	    Resources::Form *get_form () { return owner; };
+	    virtual Gtk::Widget                 *create_editor      () = 0;
+	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form) = 0;
+	    
+	    Resources::Form *get_form () const { return owner; };
 
-	    SigC::Signal0<void> show_editor;
+	    SigC::Signal1<void, bool> selected;
+	    SigC::Signal0<void>       request_edit;
 	    
 	private:
 	    // Persistance
-	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node) = 0;
-	    virtual void save (xmlNodePtr node) const = 0;
+	    virtual bool load (StorageNode &node) = 0;
+	    virtual void save (StorageNode &node) const = 0;
 	    virtual void save_rcp (ostream &ostr) const = 0;
 	    friend ostream& operator<< (ostream &ostr, const Widget *res);
 	    
