@@ -1,4 +1,4 @@
-//$Id: form-res.cc,v 1.19 2001/09/05 17:08:52 cactus Exp $ -*- c++ -*-
+//$Id: form-res.cc,v 1.21 2001/09/22 19:21:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,8 @@
 #include "form-res.h"
 
 #include "form-editor/widget.h"
+#include "form-editor/widget-util.h"
+
 #include "form-editor/label.h"
 #include "form-editor/button.h"
 #include "form-editor/pushbutton.h"
@@ -28,6 +30,7 @@
 #include "form-editor/list.h"
 #include "form-editor/popup-trigger.h"
 #include "form-editor/scrollbar.h"
+#include "form-editor/text-field.h"
 
 using namespace Guikachu::Resources;
 using namespace Guikachu;
@@ -70,51 +73,14 @@ void Form::show_ui ()
     gui->show ();
 }
 
-Widgets::Widget* Form::create_widget (Widgets::Type type)
+Widgets::Widget* Form::create_widget (Widgets::Type  type,
+				      const string  &id_ = "")
 {
-    string prefix;
-
-    switch (type)
-    {
-    case Widgets::WIDGET_LABEL:
-	prefix = "label";
-	break;
-    case Widgets::WIDGET_BUTTON:
-	prefix = "button";
-	break;
-    case Widgets::WIDGET_PUSHBUTTON:
-	prefix = "pushbutton";
-	break;
-    case Widgets::WIDGET_GRAFFITI:
-	prefix = "graffiti";
-	break;
-    case Widgets::WIDGET_SELECTOR_TRIGGER:
-	prefix = "sel_trigger";
-	break;
-    case Widgets::WIDGET_CHECKBOX:
-	prefix = "check";
-	break;
-    case Widgets::WIDGET_LIST:
-	prefix = "list";
-	break;
-    case Widgets::WIDGET_POPUP_TRIGGER:
-	prefix = "popup_trigger";
-	break;
-    case Widgets::WIDGET_SCROLLBAR:
-	prefix = "scrollbar";
-	break;
-    case Widgets::WIDGET_NONE:
-	g_assert_not_reached ();
-	return 0;
-	break;
-    }
+    string id = id_;
+    
+    if (id == "")
+	id = ResourceManager::create_id (Widgets::type_id_from_type (type));
     
-    return create_widget (type, ResourceManager::create_id (prefix));
-}
-
-Widgets::Widget* Form::create_widget (Widgets::Type type,
-				      const string& id)
-{
     if (!ResourceManager::register_id (id))
 	return 0;
 	
@@ -149,6 +115,9 @@ Widgets::Widget* Form::create_widget (Widgets::Type type,
     case Widgets::WIDGET_SCROLLBAR:
 	widget = new Widgets::ScrollBar (this, id);
 	break;
+    case Widgets::WIDGET_TEXT_FIELD:
+	widget = new Widgets::TextField (this, id);
+	break;
     case Widgets::WIDGET_NONE:
 	g_assert_not_reached ();
 	return 0;
