@@ -1,4 +1,4 @@
-//$Id: menu-res.h,v 1.3 2001/02/25 19:10:11 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.h,v 1.5 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifndef GUIKATCHU_MENU_RES_H
-#define GUIKATCHU_MENU_RES_H
+#ifndef GUIKACHU_MENU_RES_H
+#define GUIKACHU_MENU_RES_H
 
 namespace Guikachu
 {
@@ -69,11 +69,11 @@ namespace Guikachu
 	    void set_submenus (const vector<Submenu>& submenus);
 	    
 	private:
-	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
-	    virtual void save (xmlNodePtr node) const;
+	    virtual bool load (StorageNode &node);
+	    virtual void save (StorageNode &node) const;
 	    virtual void save_rcp (ostream &ostr) const;
 	};
     };
 };
 
-#endif /* !GUIKATCHU_DIALOGRES_H */
+#endif /* !GUIKACHU_MENU_RES_H */
