@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.12 2001/08/10 16:10:34 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.14 2001/08/28 15:00:21 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -95,7 +95,8 @@ GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
 
 GUI::MenuWindow::~MenuWindow ()
 {
-    window->destroy ();
+//    window->destroy ();
+    gtk_widget_destroy (GTK_WIDGET (window->gtkobj ()));
     gtk_object_unref (GTK_OBJECT (gui));
 }
 
@@ -115,11 +116,11 @@ void GUI::MenuWindow::update ()
 {
     update_block = true;
     
-    gchar *title_buf = g_strdup_printf (_("Menu: %s"), res->get_id ().c_str ());
+    gchar *title_buf = g_strdup_printf (_("Menu: %s"), res->id ().c_str ());
     window->set_title (title_buf);
     g_free (title_buf);
 
-    id_entry->set_text (res->get_id ());
+    id_entry->set_text (res->id);
 
     submenus = res->get_submenus ();
 
@@ -217,7 +218,7 @@ void GUI::MenuWindow::clist_sel_row (gint row, gint column,
 
     if (clist->selection ().size () != 1)
 	return;
-    
+
     reset_controls ();
     
     btnRemove->set_sensitive (true);
@@ -272,7 +273,7 @@ void GUI::MenuWindow::id_entry_cb ()
     if (update_block)
 	return;
     
-    res->set_id (id_entry->get_text ());
+    res->id = id_entry->get_text ();
 }
 
 void GUI::MenuWindow::item_id_entry_cb ()
