@@ -1,4 +1,4 @@
-//$Id: menu-win.h,v 1.6 2001/04/10 16:17:28 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.h,v 1.7 2001/09/15 21:27:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifndef GUIKATCHU_MENU_WIN_H
-#define GUIKATCHU_MENU_WIN_H
+#ifndef GUIKACHU_MENU_WIN_H
+#define GUIKACHU_MENU_WIN_H
 
 namespace Guikachu
 {
@@ -96,4 +96,4 @@ namespace Guikachu
     };
 };
 
-#endif /* !GUIKATCHU_STRING_WIN_H */
+#endif /* !GUIKACHU_MENU_WIN_H */
