@@ -1,4 +1,4 @@
-//$Id: string-res.cc,v 1.7 2001/09/02 20:06:03 cactus Exp $ -*- c++ -*-
+//$Id: string-res.cc,v 1.8 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,39 +42,35 @@ void Resources::String::show_ui ()
     gui->show ();
 }
 
-bool Resources::String::load (xmlDocPtr doc,
-			      xmlNodePtr node)
+bool Resources::String::load (StorageNode &node)
 {
-    xmlNodePtr curr_node;
-    gchar *xml_text = 0;
+    StorageNode curr_node;
+    bool text_set = false;
     
-    for (curr_node  = node->xmlChildrenNode;
-	 curr_node != NULL;
-	 curr_node  = curr_node->next)
+    for (curr_node  = node.children ();
+	 curr_node; curr_node  = curr_node.next ())
     {
-	if (!strcmp ((char*)curr_node->name, "text") && !xml_text)
+	if (curr_node.name () == "text")
 	{
-	    xml_text = (gchar*)xmlNodeListGetString (doc, curr_node->xmlChildrenNode, 1);
+	    text = curr_node.get_content ();
+	    text_set = true;
 	}
 	else
 	    g_warning ("Error parsing `string' resource: "
-		       "unexpected element `%s'", curr_node->name);
+		       "unexpected element `%s'", curr_node.name ().c_str ());
     }
 
-    if (!xml_text)
+    if (!text_set)
 	return false;
-    
-    text = xml_text;
-    xmlFree (xml_text);
 
     changed ();
     
     return true;
 }
 
-void Resources::String::save (xmlNodePtr node) const
+void Resources::String::save (StorageNode &node) const
 {
-    xmlNewChild (node, NULL, (xmlChar*)"text", (xmlChar*)string (text).c_str ());
+    node.add_node ("text", text);
 }
 
 void Resources::String::save_rcp (ostream &ostr) const
