@@ -1,4 +1,4 @@
-//$Id: propertytable.h,v 1.2 2001/04/27 20:23:43 cactus Exp $ -*- c++ -*-
+//$Id: propertytable.h,v 1.4 2001/08/31 16:11:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,6 +20,8 @@
 #define GUIKACHU_WIDGETS_PROPERTY_TABLE_H
 
 #include <gtk--/table.h>
+#include <gtk--/text.h> // FIXME: is this include really necessary?
+#include <gtk--/accelgroup.h>
 
 namespace Guikachu
 {
@@ -27,14 +29,27 @@ namespace Guikachu
     {
 	class PropertyTable: public Gtk::Table
 	{
-	    int curr_row;
+	    Gtk::AccelGroup *accel_group;
+	    int              curr_row;
 
 	public:
 	    PropertyTable ();
+	    ~PropertyTable ();
+	    
 	    void add_separator ();
-	    void add (const string& label,
-		      Gtk::Widget& control,
-		      const string& tooltip = "");
+
+	    void add (const string &label,
+		      Gtk::Widget  &control,
+		      const string &tooltip = "");
+
+	    void add (const string &label,
+		      Gtk::Text    &control,
+		      const string &tooltip = "");
+	protected:
+	    Gtk::Widget *create_label (const string &label,
+				       Gtk::Widget  &control,
+				       const string &tooltip);
+	    void parent_changed_cb (Gtk::Widget *old_parent);
 	};
     }
 }
